@@ -96,12 +96,16 @@ typedef struct appdata {
     canvas_item_t *gps_item;      // the purple curcle
   } track;
 
+  GtkWidget *menu_item_wms_clear;
+  GtkWidget *menu_item_wms_adjust;
+
 } appdata_t;
 
 #include "map.h"
 #include "map_hl.h"
 #include "osm_api.h"
 #include "statusbar.h"
+#include "area_edit.h"
 #include "project.h"
 #include "settings.h"
 #include "diff.h"
