@@ -106,4 +106,7 @@ canvas_item_t *canvas_image_new(struct map_s *map, canvas_group_t group,
 				GdkPixbuf *pix, gint x, gint y, 
 				float hscale, float vscale);
 
+void canvas_image_move(canvas_item_t *item, gint x, gint y, 
+		       float hscale, float vscale);
+
 #endif // CANVAS_H
