@@ -25,10 +25,14 @@ typedef struct iconbar_s {
   GtkWidget *trash;
   GtkWidget *node_add;
 
+  GtkWidget *cancel;
+  GtkWidget *ok;
 } iconbar_t;
 
 GtkWidget *iconbar_new(appdata_t *appdata);
 void icon_bar_map_item_selected(appdata_t *appdata, map_item_t *map_item,
 				gboolean selected);
+void icon_bar_map_cancel_ok(appdata_t *appdata, gboolean cancel, gboolean ok);
+void icon_bar_map_action_idle(appdata_t *appdata, gboolean idle);
 
 #endif // ICONBAR_H
