@@ -329,24 +329,38 @@ void info_dialog(appdata_t *appdata) {
   GtkWidget *table = gtk_table_new(2, 2, FALSE);  // x, y
 
   /* ------------ user ----------------- */
-  label = gtk_label_new(_("User:"));
+  char *u_str = NULL;
+  if(user) u_str = g_strdup_printf(_("User: %s"), user->name);
+  else     u_str = g_strdup_printf(_("User: ---"));
+  label = gtk_label_new(u_str);
   gtk_table_attach_defaults(GTK_TABLE(table),  label, 0, 1, 0, 1);
-  if(user) label = gtk_label_new(user->name);
-  else     label = gtk_label_new("---");
-  gtk_table_attach_defaults(GTK_TABLE(table),  label, 1, 2, 0, 1);
+  g_free(u_str);
 
   /* ------------ time ----------------- */
-  label = gtk_label_new(_("Time:"));
-  gtk_table_attach_defaults(GTK_TABLE(table),  label, 0, 1, 1, 2);
+
   struct tm *loctime = localtime(&stime);
   char time_str[32];
   strftime(time_str, sizeof(time_str), "%x %X", loctime);
-  label = gtk_label_new(time_str);
-  gtk_table_attach_defaults(GTK_TABLE(table),  label, 1, 2, 1, 2);
+  char *t_str = g_strdup_printf(_("Time: %s"), time_str);
+  label = gtk_label_new(t_str);
+  g_free(t_str);
+  gtk_table_attach_defaults(GTK_TABLE(table),  label, 1, 2, 0, 1);
 
+  /* ------------ coordinate (only for nodes) ----------------- */
+  if(appdata->map->selected.type == MAP_TYPE_NODE) {
+    char pos_str[32];
+    pos_lat_str(pos_str, sizeof(pos_str), appdata->map->selected.node->pos.lat);
+    label = gtk_label_new(pos_str);
+    gtk_table_attach_defaults(GTK_TABLE(table),  label, 0, 1, 1, 2);
+    pos_lat_str(pos_str, sizeof(pos_str), appdata->map->selected.node->pos.lon);
+    label = gtk_label_new(pos_str);
+    gtk_table_attach_defaults(GTK_TABLE(table),  label, 1, 2, 1, 2);
+  }
+    
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(context->dialog)->vbox), table, 
 		     FALSE, FALSE, 0);
 
+
   /* ------------ tags ----------------- */
 
   gtk_box_pack_start(GTK_BOX(GTK_DIALOG(context->dialog)->vbox),
