@@ -117,7 +117,13 @@ cb_menu_wms_clear(GtkWidget *window, gpointer data) {
   wms_remove(appdata);
 }
 
-#if 1
+static void 
+cb_menu_wms_adjust(GtkWidget *window, gpointer data) {
+  appdata_t *appdata = (appdata_t*)data;
+  map_action_set(appdata, MAP_ACTION_BG_ADJUST);
+}
+
+#if 1  // mainly for testing
 static void 
 cb_menu_redraw(GtkWidget *window, gpointer data) {
   appdata_t *appdata = (appdata_t*)data;
@@ -264,11 +270,20 @@ void menu_create(appdata_t *appdata) {
   g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_wms_import), 
 		   appdata);
 
-  item = gtk_menu_item_new_with_label( _("Clear...") );
+  appdata->menu_item_wms_clear = item = 
+    gtk_menu_item_new_with_label( _("Clear...") );
   gtk_menu_append(GTK_MENU_SHELL(submenu), item);
+  gtk_widget_set_sensitive(item, FALSE);
   g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_wms_clear), 
 		   appdata);
 
+  appdata->menu_item_wms_adjust = item = 
+    gtk_menu_item_new_with_label( _("Adjust...") );
+  gtk_menu_append(GTK_MENU_SHELL(submenu), item);
+  gtk_widget_set_sensitive(item, FALSE);
+  g_signal_connect(item, "activate", GTK_SIGNAL_FUNC(cb_menu_wms_adjust), 
+		   appdata);
+
 
   /* -------------------- track submenu -------------------- */
 
@@ -347,6 +362,10 @@ void cleanup(appdata_t *appdata) {
   while(gtk_events_pending())
     gtk_main_iteration();
 
+  /* save a dirty project file */
+  if(appdata->project && appdata->project->dirty)
+    project_save(appdata, appdata->project);
+
   map_remove_bg_image(appdata->map);
 
   osm_free(appdata->osm);
@@ -499,13 +518,18 @@ int main(int argc, char *argv[]) {
   printf("loading osm\n");
   appdata.osm = osm_parse(appdata.project->osm);
   if(!appdata.osm) {
-    printf("parsing failed\n");
+    errorf(GTK_WIDGET(appdata.window), _("Parsing of OSM data failed!"));
     cleanup(&appdata);
     return 0;
   }
 
   printf("parsing ok\n");
 
+  if(!osm_sanity_check(GTK_WIDGET(appdata.window), appdata.osm)) {
+    cleanup(&appdata);
+    return 0;
+  }
+
   printf("loading diff\n");
   diff_restore(&appdata, appdata.project, appdata.osm);
 
