@@ -145,7 +145,8 @@ static void map_node_select(appdata_t *appdata, node_t *node) {
     new_map_item = g_new0(map_item_t, 1);
     memcpy(new_map_item, map_item, sizeof(map_item_t));
     new_map_item->highlight = TRUE;
-    map_hl_circle_new(map, CANVAS_GROUP_NODES_HL, new_map_item, x, y, RADIUS, HIGHLIGHT2_COLOR);
+    map_hl_circle_new(map, CANVAS_GROUP_NODES_HL, new_map_item, 
+		      x, y, RADIUS, HIGHLIGHT2_COLOR);
   }
 }
 
@@ -180,7 +181,8 @@ static void map_way_select(appdata_t *appdata, way_t *way) {
       gint x = node_chain->node->lpos.x;
       gint y = node_chain->node->lpos.y;
 
-      map_hl_circle_new(map, CANVAS_GROUP_NODES_HL, new_map_item, x, y, RADIUS, HIGHLIGHT2_COLOR);
+      map_hl_circle_new(map, CANVAS_GROUP_NODES_HL, new_map_item, 
+			x, y, RADIUS, HIGHLIGHT2_COLOR);
     }
 
     node_chain = node_chain->next;
@@ -778,8 +780,6 @@ static void map_button_press(map_t *map, gint x, gint y) {
       item_is_selected_node(map, map->pen_down.on_item);
 
   switch(map->action) {
-  case MAP_ACTION_IDLE:
-    break;
   case MAP_ACTION_NODE_ADD:
     map_hl_cursor_draw(map, x, y);
     break;
@@ -788,10 +788,30 @@ static void map_button_press(map_t *map, gint x, gint y) {
   }
 }
 
+/* move the background image (wms data) during wms adjustment */
+static void map_bg_adjust(map_t *map, gint x, gint y) {    
+  g_assert(map->appdata);
+  g_assert(map->appdata->osm);
+  g_assert(map->appdata->osm->bounds);
+
+  x += map->appdata->osm->bounds->min.x + map->bg_offset.x -
+    map->pen_down.at.x;
+  y += map->appdata->osm->bounds->min.y + map->bg_offset.y -
+    map->pen_down.at.y;
+
+  canvas_image_move(map->bg_item, x, y, map->bg_scale.x, map->bg_scale.y);
+}
+
 static void map_button_release(map_t *map, gint x, gint y) {
   map->pen_down.is = FALSE;
 
   switch(map->action) {
+  case MAP_ACTION_BG_ADJUST:
+    map_bg_adjust(map, x, y);
+    map->bg_offset.x += x - map->pen_down.at.x;
+    map->bg_offset.y += y - map->pen_down.at.y;
+    break;
+
   case MAP_ACTION_IDLE:
     /* check if distance to press is above drag limit */
     if(!map->pen_down.drag)
@@ -818,7 +838,7 @@ static void map_button_release(map_t *map, gint x, gint y) {
 	  map->pen_down.on_item = 
 	    map_real_item_at(map, map->pen_down.at.x, map->pen_down.at.y);
 	  
-	map_handle_click(map->appdata, map);
+	  map_handle_click(map->appdata, map);
 	}
       }
     } else {
@@ -847,7 +867,7 @@ static void map_button_release(map_t *map, gint x, gint y) {
     node_t *node = osm_node_new(map->appdata->osm, x, y);
     map_node_draw(map, node);
 
-    map->action = MAP_ACTION_IDLE;
+    map_action_set(map->appdata, MAP_ACTION_IDLE);
 
     map_item_deselect(map->appdata);
     map_node_select(map->appdata, node);
@@ -940,6 +960,10 @@ static gboolean map_motion_notify_event(GtkWidget *widget,
     map->pen_down.drag = distance_above(map, x, y, MAP_DRAG_LIMIT);
   
   switch(map->action) {
+  case MAP_ACTION_BG_ADJUST:
+    map_bg_adjust(map, x, y);
+    break;
+
   case MAP_ACTION_IDLE:
     if(map->pen_down.drag) {
       /* just scroll if we didn't drag an selected item */
@@ -1130,7 +1154,85 @@ void map_paint(appdata_t *appdata) {
 /* called from several icons like e.g. "node_add" */
 void map_action_set(appdata_t *appdata, map_action_t action) {
   printf("map action set to %d\n", action);
+
+  /* returning from this action */
+  switch(appdata->map->action) {
+  case MAP_ACTION_BG_ADJUST:
+    gtk_widget_set_sensitive(appdata->menu_item_wms_adjust, TRUE);
+    break;
+  default:
+    break;
+  }
+
   appdata->map->action = action;
+
+  /* enable/disable ok/cancel buttons */
+  // MAP_ACTION_IDLE=0, _NODE_ADD, _BG_ADJUST
+  const gboolean ok_state[] = { FALSE, FALSE, TRUE };
+  const gboolean cancel_state[] = { FALSE, TRUE, TRUE };
+  g_assert(action < sizeof(ok_state)/sizeof(gboolean));
+
+  icon_bar_map_cancel_ok(appdata, cancel_state[action], ok_state[action]);
+
+  switch(action) {
+  case MAP_ACTION_BG_ADJUST:
+    /* an existing selection only causes confusion ... */
+    gtk_widget_set_sensitive(appdata->menu_item_wms_adjust, FALSE);
+    map_item_deselect(appdata);
+    break;
+
+  default:
+    break;
+  }
+
+  icon_bar_map_action_idle(appdata, action == MAP_ACTION_IDLE);
+
+  const char *str_state[] = { 
+    NULL, 
+    _("Please place a node"),
+    _("Adjust background image position"),
+  };
+
+  statusbar_set(appdata, str_state[action]);
+}
+
+void map_action_cancel(appdata_t *appdata) {
+  map_t *map = appdata->map;
+
+  switch(map->action) {
+  case MAP_ACTION_BG_ADJUST:
+    /* undo all changes to bg_offset */
+    map->bg_offset.x = appdata->project->wms_offset.x;
+    map->bg_offset.y = appdata->project->wms_offset.y;
+
+    gint x = map->appdata->osm->bounds->min.x + map->bg_offset.x;
+    gint y = map->appdata->osm->bounds->min.y + map->bg_offset.y;
+    canvas_image_move(map->bg_item, x, y, map->bg_scale.x, map->bg_scale.y);
+    break;
+
+  default:
+    break;
+  }
+
+  map_action_set(appdata, MAP_ACTION_IDLE);
+}
+
+void map_action_ok(appdata_t *appdata) {
+  map_t *map = appdata->map;
+
+  switch(map->action) {
+  case MAP_ACTION_BG_ADJUST:
+    /* save changes to bg_offset in project */
+    appdata->project->wms_offset.x = map->bg_offset.x;
+    appdata->project->wms_offset.y = map->bg_offset.y;
+    appdata->project->dirty = TRUE;
+    break;
+
+  default:
+    break;
+  }
+
+  map_action_set(appdata, MAP_ACTION_IDLE);
 }
 
 static void map_item_chain_destroy(map_item_chain_t *chain) {
@@ -1371,14 +1473,14 @@ void map_set_bg_image(map_t *map, char *filename) {
 
   map->bg_pix = gdk_pixbuf_new_from_file(filename, NULL);
 
-  float hscale = (float)(bounds->max.x - bounds->min.x)/
+  /* calculate required scale factor */
+  map->bg_scale.x = (float)(bounds->max.x - bounds->min.x)/
     (float)gdk_pixbuf_get_width(map->bg_pix);
-
-  float vscale = (float)(bounds->max.y - bounds->min.y)/
+  map->bg_scale.y = (float)(bounds->max.y - bounds->min.y)/
     (float)gdk_pixbuf_get_height(map->bg_pix);
 
   map->bg_item = canvas_image_new(map, CANVAS_GROUP_BG, map->bg_pix, 
-			  bounds->min.x, bounds->min.y, hscale, vscale);
+	  bounds->min.x, bounds->min.y, map->bg_scale.x, map->bg_scale.y);
 
   canvas_item_destroy_connect(map->bg_item, 
           G_CALLBACK(map_bg_item_destroy_event), map);
