@@ -49,8 +49,17 @@
 #define MAP_DRAG_LIMIT   16
 #endif
 
-typedef enum { MAP_TYPE_ILLEGAL=0, MAP_TYPE_NODE, MAP_TYPE_WAY } map_type_t;
-typedef enum { MAP_ACTION_IDLE=0, MAP_ACTION_NODE_ADD } map_action_t;
+typedef enum { 
+  MAP_TYPE_ILLEGAL=0, 
+  MAP_TYPE_NODE, 
+  MAP_TYPE_WAY 
+} map_type_t;
+
+typedef enum { 
+  MAP_ACTION_IDLE=0, 
+  MAP_ACTION_NODE_ADD, 
+  MAP_ACTION_BG_ADJUST 
+} map_action_t;
 
 typedef struct map_highlight_s {
   canvas_item_t *item;
@@ -93,6 +102,8 @@ typedef struct map_s {
 
   GdkPixbuf *bg_pix;
   canvas_item_t *bg_item;
+  struct { float x, y; } bg_offset;
+  struct { float x, y; } bg_scale;
 
   map_action_t action;             // current action in progress
 
@@ -124,8 +135,10 @@ void map_clear(appdata_t *appdata);
 void map_paint(appdata_t *appdata);
 
 void map_action_set(appdata_t *appdata, map_action_t action);
-void map_delete_selected(appdata_t *appdata);
+void map_action_cancel(appdata_t *appdata);
+void map_action_ok(appdata_t *appdata);
 
+void map_delete_selected(appdata_t *appdata);
 
 /* track stuff */
 void map_track_draw(map_t *map, struct track_s *track);
