@@ -758,11 +758,11 @@ static osm_t *osm_parse_doc(xmlDocPtr doc) {
 void osm_free(osm_t *osm) {
   if(!osm) return;
 
-  osm_bounds_free(osm->bounds);
-  osm_users_free(osm->user);
-  osm_nodes_free(osm->node);
-  osm_ways_free(osm->way);
-  osm_relations_free(osm->relation);
+  if(osm->bounds)   osm_bounds_free(osm->bounds);
+  if(osm->user)     osm_users_free(osm->user);
+  if(osm->node)     osm_nodes_free(osm->node);
+  if(osm->way)      osm_ways_free(osm->way);
+  if(osm->relation) osm_relations_free(osm->relation);
   g_free(osm);
 }
 
@@ -789,6 +789,20 @@ osm_t *osm_parse(char *filename) {
   return osm_parse_doc(doc); 
 }
 
+gboolean osm_sanity_check(GtkWidget *parent, osm_t *osm) {
+  if(!osm->bounds) {
+    errorf(parent, _("Ivalid data in OSM file:\n"
+		     "Boundary box missing!"));
+    return FALSE;
+  }
+  if(!osm->node) {
+    errorf(parent, _("Ivalid data in OSM file:\n"
+		     "No drawable content found!"));
+    return FALSE;
+  }
+  return TRUE;
+}
+
 /* ------------------------- misc access functions -------------- */
 
 char *osm_way_get_value(way_t *way, char *key) {
