@@ -66,6 +66,7 @@ typedef struct {
   char *url, *filename;
   gboolean cancelled;
   CURLcode res;
+  long response;
   char buffer[CURL_ERROR_SIZE];
 
   int percent;
@@ -84,11 +85,13 @@ typedef struct {
 
 } osm_upload_context_t;
 
+#if 0 // todo: figure out how to stop a curl transfer
 /* Our usual callback function */
 static void on_cancel(GtkWidget *widget, gpointer data) {
   osm_download_context_t *context = (osm_download_context_t*)data;
   context->cancelled = TRUE;
 }
+#endif
 
 static int my_progress_func(osm_download_context_t *context,
 			    double t, /* dltotal */ double d, /* dlnow */
@@ -120,6 +123,8 @@ static void *my_thread(void *ptr) {
       context->res = curl_easy_perform(curl);
       printf("curl perform returned with %d\n", context->res);
     
+      curl_easy_getinfo(curl, CURLINFO_RESPONSE_CODE, &context->response);
+
       fclose(outfile);
     }
 
@@ -133,7 +138,6 @@ static void *my_thread(void *ptr) {
   return NULL;
 }
 
-/* called whenever a highlight item is to be destroyed */
 static gint wait_dialog_destroy_event(GtkWidget *widget, gpointer data) {
   osm_download_context_t *context = (osm_download_context_t*)data;
 
@@ -169,7 +173,7 @@ static gint wait_dialog_destroy_event(GtkWidget *widget, gpointer data) {
   context->wait_dialog = gtk_dialog_new();
   gtk_dialog_set_has_separator(GTK_DIALOG(context->wait_dialog), FALSE);
   gtk_window_set_title(GTK_WINDOW(context->wait_dialog), _("Downloading..."));
-  gtk_window_set_default_size(GTK_WINDOW(context->wait_dialog), 300, 50);
+  gtk_window_set_default_size(GTK_WINDOW(context->wait_dialog), 300, 10);
 
   gtk_window_set_modal(GTK_WINDOW(context->wait_dialog), TRUE);
   gtk_window_set_transient_for(GTK_WINDOW(context->wait_dialog), 
@@ -178,13 +182,15 @@ static gint wait_dialog_destroy_event(GtkWidget *widget, gpointer data) {
   context->pbar = gtk_progress_bar_new_with_adjustment(adj);
   gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(context->wait_dialog)->vbox), 
 			      context->pbar);
-  
+
+#if 0  
   GtkWidget *button = gtk_button_new_with_label(_("Cancel"));
   gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		     GTK_SIGNAL_FUNC(on_cancel), (gpointer)context);
   gtk_container_add(GTK_CONTAINER(GTK_DIALOG(context->wait_dialog)->
 				  action_area), button);
-  
+#endif  
+
   gtk_signal_connect(GTK_OBJECT(context->wait_dialog), 
 	     "destroy", G_CALLBACK(wait_dialog_destroy_event), context);
  
@@ -214,7 +220,13 @@ static gint wait_dialog_destroy_event(GtkWidget *widget, gpointer data) {
 
   gboolean result = (context->res == 0);
   if(!result) 
-    errorf(parent, "Download failed with message: %s", context->buffer);
+    errorf(parent, _("Download failed with message:\n\n%s"), context->buffer);
+
+  if(context->response != 200) {
+    errorf(parent, _("Download failed with code %ld:\n\n%s\n"), 
+	   context->response, osm_http_message(context->response));
+    g_remove(context->filename);
+  }
 
   printf("clean up\n");
   /* clean up */
@@ -457,7 +469,7 @@ static void osm_upload_nodes(osm_upload_context_t *context) {
 
       if(osm_delete_item(&context->log, url, cred)) {
 	node->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_DELETED);
-	project->dirty = TRUE;
+	project->data_dirty = TRUE;
       }
       
       g_free(cred);
@@ -485,7 +497,7 @@ static void osm_upload_nodes(osm_upload_context_t *context) {
 			   (node->flags & OSM_FLAG_NEW)?&(node->id):NULL)) {
 
 	  node->flags &= ~(OSM_FLAG_DIRTY | OSM_FLAG_NEW);
-	  project->dirty = TRUE;
+	  project->data_dirty = TRUE;
 	}
 
 	g_free(cred);
@@ -522,7 +534,7 @@ static void osm_upload_ways(osm_upload_context_t *context) {
 		     project->username, project->password);
 	if(osm_update_item(&context->log, xml_str, url, cred, NULL)) {
 	  way->flags &= ~OSM_FLAG_DIRTY;
-	  project->dirty = TRUE;
+	  project->data_dirty = TRUE;
 	}
 
 	g_free(cred);
@@ -708,14 +720,14 @@ void osm_upload(appdata_t *appdata, osm_t *osm, project_t *project) {
   appendf(&context->log, _("Upload done.\n"));
 
   gboolean reload_map = FALSE;
-  if(project->dirty) {
+  if(project->data_dirty) {
     appendf(&context->log, _("Server data has been modified.\n"));
     appendf(&context->log, _("Downloading updated osm data ...\n"));
 
     if(osm_download(context->dialog, appdata, project)) {
       appendf(&context->log, _("Download successful!\n"));
       appendf(&context->log, _("The map will be reloaded.\n"));
-      project->dirty = FALSE;
+      project->data_dirty = FALSE;
       reload_map = TRUE;
     } else
       appendf(&context->log, _("Download failed!\n"));
