@@ -34,6 +34,7 @@ typedef struct {
   GtkWidget *dialog, *fsize, *diff_stat, *diff_remove;
   GtkWidget *desc, *server;
   GtkWidget *minlat, *minlon, *maxlat, *maxlon;
+  area_edit_t area_edit;
 } project_context_t;
 
 void project_free(project_t *project) {
@@ -71,7 +72,7 @@ void project_filesize(project_context_t *context) {
     gtk_dialog_set_response_sensitive(GTK_DIALOG(context->dialog), 
 				      GTK_RESPONSE_ACCEPT, 0);
   } else {
-    if(!context->project->dirty)
+    if(!context->project->data_dirty)
       str = g_strdup_printf(_("%d bytes present"), 
 			    file_length(context->project->osm));
     else
@@ -79,7 +80,7 @@ void project_filesize(project_context_t *context) {
 
     /* project also must not be dirty to proceed */
     gtk_dialog_set_response_sensitive(GTK_DIALOG(context->dialog), 
-			GTK_RESPONSE_ACCEPT, !context->project->dirty);
+			GTK_RESPONSE_ACCEPT, !context->project->data_dirty);
   }
 
   if(str) {
@@ -110,11 +111,19 @@ static void project_update(project_context_t *context) {
   if(context->project->server) g_free(context->project->server);
   context->project->server = g_strdup(gtk_entry_get_text(
 				       GTK_ENTRY(context->server)));
-  
-  context->project->min.lat = pos_lat_get(context->minlat);
-  context->project->min.lon = pos_lon_get(context->minlon);
-  context->project->max.lat = pos_lat_get(context->maxlat);
-  context->project->max.lon = pos_lon_get(context->maxlon);
+}
+
+static void on_edit_clicked(GtkButton *button, gpointer data) {
+  project_context_t *context = (project_context_t*)data;
+
+  if(area_edit(&context->area_edit)) {
+    printf("coordinates changed!!\n");
+
+    pos_lon_label_set(context->minlat, context->project->min.lat);
+    pos_lon_label_set(context->minlon, context->project->min.lon);
+    pos_lon_label_set(context->maxlat, context->project->max.lat);
+    pos_lon_label_set(context->maxlon, context->project->max.lon);
+  }
 }
 
 static void on_download_clicked(GtkButton *button, gpointer data) {
@@ -132,8 +141,8 @@ static void on_download_clicked(GtkButton *button, gpointer data) {
 	       GTK_DIALOG_DESTROY_WITH_PARENT,
 	       GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
 	       _("You have saved changes for the current data set. "
-		 "Downloading new data may result in conflicts. Do you "
-		 "really want to download new data?"));
+		 "Downloading new data may result in loss of these changes. "
+		 "Do you really want to download new data?"));
       
     gtk_window_set_title(GTK_WINDOW(dialog), _("Really download?"));
       
@@ -150,7 +159,7 @@ static void on_download_clicked(GtkButton *button, gpointer data) {
   }
 
   if(osm_download(context->dialog, context->appdata, context->project)) {
-    context->project->dirty = FALSE;
+    context->project->data_dirty = FALSE;
     project_filesize(context);
   } else
     printf("download failed\n"); 
@@ -166,7 +175,7 @@ static void on_diff_remove_clicked(GtkButton *button, gpointer data) {
 	     GTK_WINDOW(context->dialog),
 	     GTK_DIALOG_DESTROY_WITH_PARENT,
 	     GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
-	       _("Do you really wanto to remove the diff file? This "
+	       _("Do you really want to remove the diff file? This "
 		 "will delete all changes you've made so far and which "
 		 "you didn't upload yet."));
       
@@ -194,7 +203,7 @@ void project_save(appdata_t *appdata, project_t *project) {
   xmlDocPtr doc = xmlNewDoc(BAD_CAST "1.0");
   xmlNodePtr node, root_node = xmlNewNode(NULL, BAD_CAST "proj");
   xmlNewProp(root_node, BAD_CAST "name", BAD_CAST project->name);
-  if(project->dirty)
+  if(project->data_dirty)
     xmlNewProp(root_node, BAD_CAST "dirty", BAD_CAST "true");
 
   xmlDocSetRootElement(doc, root_node);
@@ -223,6 +232,10 @@ void project_save(appdata_t *appdata, project_t *project) {
   node = xmlNewChild(root_node, NULL, BAD_CAST "wms", NULL);
   xmlNewProp(node, BAD_CAST "server", BAD_CAST project->wms_server);
   xmlNewProp(node, BAD_CAST "path", BAD_CAST project->wms_path);
+  snprintf(str, sizeof(str), "%d", project->wms_offset.x);
+  xmlNewProp(node, BAD_CAST "x-offset", BAD_CAST str);
+  snprintf(str, sizeof(str), "%d", project->wms_offset.y);
+  xmlNewProp(node, BAD_CAST "y-offset", BAD_CAST str);
 
   xmlSaveFormatFileEnc(project_file, doc, "UTF-8", 1);
   xmlFreeDoc(doc);
@@ -237,7 +250,8 @@ project_t *project_open(appdata_t *appdata, char *name) {
   LIBXML_TEST_VERSION;
 
   /* build project path */
-  project->path = g_strdup_printf("%s%s/", appdata->settings->base_path, name);
+  project->path = g_strdup_printf("%s%s/", 
+		  appdata->settings->base_path, name);
   project->name = g_strdup(name);
 
   /* make sure project base path exists */
@@ -256,7 +270,7 @@ project_t *project_open(appdata_t *appdata, char *name) {
     project->desc = g_strdup(_("OSM2Go test project"));
 
     /* no data downloaded yet */
-    project->dirty = TRUE;
+    project->data_dirty = TRUE;
 
     /* use global server/access settings */
     project->server   = g_strdup(appdata->settings->server);
@@ -271,8 +285,8 @@ project_t *project_open(appdata_t *appdata, char *name) {
     project->osm = g_strdup_printf("%s%s.osm", project->path, name);
 
     /* around my home ... */
-    project->min.lat = 49.018;    project->min.lon = 8.375;
-    project->max.lat = 49.03971;  project->max.lon = 8.40461;
+    project->min.lat = 49.02;  project->min.lon = 8.38;
+    project->max.lat = 49.04;  project->max.lon = 8.40;
 
   } else {
     xmlDoc *doc = NULL;
@@ -296,10 +310,10 @@ project_t *project_open(appdata_t *appdata, char *name) {
 	  char *str;
 
 	  if((str = (char*)xmlGetProp(cur_node, BAD_CAST "dirty"))) {
-	    project->dirty = (strcasecmp(str, "true") == 0);
+	    project->data_dirty = (strcasecmp(str, "true") == 0);
 	    xmlFree(str);
 	  } else
-	    project->dirty = FALSE;
+	    project->data_dirty = FALSE;
 
 	  xmlNode *node = cur_node->children;
 
@@ -335,6 +349,14 @@ project_t *project_open(appdata_t *appdata, char *name) {
 		  project->wms_path = g_strdup(str);
 		  xmlFree(str);
 		} 
+		if((str = (char*)xmlGetProp(node, BAD_CAST "x-offset"))) {
+		  project->wms_offset.x = strtoul(str, NULL, 10);
+		  xmlFree(str);
+		} 
+		if((str = (char*)xmlGetProp(node, BAD_CAST "y-offset"))) {
+		  project->wms_offset.y = strtoul(str, NULL, 10);
+		  xmlFree(str);
+		} 
 
 	      } else if(strcasecmp((char*)node->name, "osm") == 0) {
 		str = (char*)xmlNodeListGetString(doc, node->children, 1);
@@ -383,8 +405,12 @@ project_t *project_open(appdata_t *appdata, char *name) {
   context->appdata = appdata;
   context->project = project;
 
+  context->area_edit.min = &project->min;
+  context->area_edit.max = &project->max;
+
   char *str = g_strdup_printf(_("Project - %s"), name);
-  context->dialog = gtk_dialog_new_with_buttons(str,
+  context->area_edit.parent = 
+    context->dialog = gtk_dialog_new_with_buttons(str,
 	  GTK_WINDOW(appdata->window), GTK_DIALOG_MODAL,
           GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 	  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
@@ -393,50 +419,56 @@ project_t *project_open(appdata_t *appdata, char *name) {
 #ifdef USE_HILDON
   /* making the dialog a little wider makes it less "crowded" */
   gtk_window_set_default_size(GTK_WINDOW(context->dialog), 640, 100);
+#else
+  gtk_window_set_default_size(GTK_WINDOW(context->dialog), 400, 100);
 #endif
 
   GtkWidget *download, *label;
-  GtkWidget *table = gtk_table_new(3, 6, FALSE);  // x, y
-  gtk_table_set_col_spacing(GTK_TABLE(table), 0, 8);
+  GtkWidget *table = gtk_table_new(4, 6, FALSE);  // x, y
 
   label = gtk_label_new(_("Description:"));
   gtk_misc_set_alignment(GTK_MISC(label), 1.f, 0.5f);
   gtk_table_attach_defaults(GTK_TABLE(table),  label, 0, 1, 0, 1);
   context->desc = gtk_entry_new();
   gtk_entry_set_text(GTK_ENTRY(context->desc), project->desc);
-  gtk_table_attach_defaults(GTK_TABLE(table),  context->desc, 1, 3, 0, 1);
+  gtk_table_attach_defaults(GTK_TABLE(table),  context->desc, 1, 4, 0, 1);
 
-  gtk_table_set_row_spacing(GTK_TABLE(table), 0, 9);
+  gtk_table_set_row_spacing(GTK_TABLE(table), 0, 4);
 
   label = gtk_label_new(_("Latitude"));
   gtk_table_attach_defaults(GTK_TABLE(table),  label, 1, 2, 1, 2);
   label = gtk_label_new(_("Longitude"));
   gtk_table_attach_defaults(GTK_TABLE(table),  label, 2, 3, 1, 2);
 
-  label = gtk_label_new(_("From:"));
+  label = gtk_label_new(_("Min:"));
   gtk_misc_set_alignment(GTK_MISC(label), 1.f, 0.5f);
   gtk_table_attach_defaults(GTK_TABLE(table),  label, 0, 1, 2, 3);
-  context->minlat = pos_lat_entry_new(project->min.lat);
+  context->minlat = pos_lat_label_new(project->min.lat);
   gtk_table_attach_defaults(GTK_TABLE(table), context->minlat, 1, 2, 2, 3);
-  context->minlon = pos_lon_entry_new(project->min.lon);
+  context->minlon = pos_lon_label_new(project->min.lon);
   gtk_table_attach_defaults(GTK_TABLE(table), context->minlon, 2, 3, 2, 3);
 
-  label = gtk_label_new(_("To:"));
+  label = gtk_label_new(_("Max:"));
   gtk_misc_set_alignment(GTK_MISC(label), 1.f, 0.5f);
   gtk_table_attach_defaults(GTK_TABLE(table),  label, 0, 1, 3, 4);
-  context->maxlat = pos_lat_entry_new(project->max.lat);
+  context->maxlat = pos_lat_label_new(project->max.lat);
   gtk_table_attach_defaults(GTK_TABLE(table), context->maxlat, 1, 2, 3, 4);
-  context->maxlon = pos_lon_entry_new(project->max.lon);
+  context->maxlon = pos_lon_label_new(project->max.lon);
   gtk_table_attach_defaults(GTK_TABLE(table), context->maxlon, 2, 3, 3, 4);
 
-  gtk_table_set_row_spacing(GTK_TABLE(table), 3, 8);
+  GtkWidget *edit = gtk_button_new_with_label(_("Edit..."));
+  gtk_signal_connect(GTK_OBJECT(edit), "clicked",
+  		     (GtkSignalFunc)on_edit_clicked, context);
+  gtk_table_attach(GTK_TABLE(table), edit, 3, 4, 2, 4, GTK_EXPAND | GTK_FILL,0,0,0);
+
+  gtk_table_set_row_spacing(GTK_TABLE(table), 3, 4);
 
   label = gtk_label_new(_("Server:"));
   gtk_misc_set_alignment(GTK_MISC(label), 1.f, 0.5f);
   gtk_table_attach_defaults(GTK_TABLE(table),  label, 0, 1, 4, 5);
   context->server = gtk_entry_new();
   gtk_entry_set_text(GTK_ENTRY(context->server), project->server);
-  gtk_table_attach_defaults(GTK_TABLE(table),  context->server, 1, 3, 4, 5);
+  gtk_table_attach_defaults(GTK_TABLE(table),  context->server, 1, 4, 4, 5);
 
   label = gtk_label_new(_("OSM file:"));
   gtk_misc_set_alignment(GTK_MISC(label), 1.f, 0.5f);
@@ -450,7 +482,7 @@ project_t *project_open(appdata_t *appdata, char *name) {
   gtk_signal_connect(GTK_OBJECT(download), "clicked",
 		     (GtkSignalFunc)on_download_clicked, context);
   gtk_box_pack_start(GTK_BOX(hbox), download, FALSE, FALSE, 0);
-  gtk_table_attach_defaults(GTK_TABLE(table), hbox, 1, 3, 5, 6);
+  gtk_table_attach_defaults(GTK_TABLE(table), hbox, 1, 4, 5, 6);
 
   label = gtk_label_new(_("Diff file:"));
   gtk_misc_set_alignment(GTK_MISC(label), 1.f, 0.5f);
@@ -466,7 +498,7 @@ project_t *project_open(appdata_t *appdata, char *name) {
   gtk_signal_connect(GTK_OBJECT(context->diff_remove), "clicked",
 		     (GtkSignalFunc)on_diff_remove_clicked, context);
   gtk_box_pack_start(GTK_BOX(hbox), context->diff_remove, FALSE, FALSE, 0);
-  gtk_table_attach_defaults(GTK_TABLE(table), hbox, 1, 3, 6, 7);
+  gtk_table_attach_defaults(GTK_TABLE(table), hbox, 1, 4, 6, 7);
   
 
   gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(context->dialog)->vbox), 
