@@ -33,10 +33,12 @@ typedef struct project_s {
 
   char *wms_server;
   char *wms_path;
+  struct { gint x, y; } wms_offset;
 
   pos_t min, max;
 
-  gboolean dirty;   /* needs to download new data */
+  gboolean data_dirty;   /* needs to download new data */
+  gboolean dirty;        /* project file needs to be written */
 } project_t;
 
 project_t *project_open(appdata_t *appdata, char *name);
