@@ -766,10 +766,27 @@ void wms_import(appdata_t *appdata) {
     return;
   }
 
+  /* this cancels any wms adjustment in progress */
+  if(appdata->map->action == MAP_ACTION_BG_ADJUST)
+    map_action_cancel(appdata);
+
   wms_t *wms = g_new0(wms_t,1);
   wms->server = g_strdup(appdata->project->wms_server);
   wms->path   = g_strdup(appdata->project->wms_path);
 
+  /* reset any background adjustments in the project ... */
+  if((appdata->project->wms_offset.x != 0)||
+     (appdata->project->wms_offset.y != 0)) {
+
+    appdata->project->wms_offset.x = 0;
+    appdata->project->wms_offset.y = 0;
+    appdata->project->dirty = TRUE;
+  }
+
+  /* ... as well as in the map */
+  appdata->map->bg_offset.x = 0;
+  appdata->map->bg_offset.y = 0;
+
   /* get server from dialog */
   if(!wms_server_dialog(appdata, wms)) {
     wms_free(wms);
@@ -777,22 +794,18 @@ void wms_import(appdata_t *appdata) {
   }
 
   /* ------------- copy values back into project ---------------- */
-  gboolean project_dirty = FALSE;
   if(strcmp(appdata->project->wms_server, wms->server) != 0) {
     g_free(appdata->project->wms_server);
     appdata->project->wms_server = g_strdup(wms->server);
-    project_dirty = TRUE;
+    appdata->project->dirty = TRUE;
   }
 
   if(strcmp(appdata->project->wms_path, wms->path) != 0) {
     g_free(appdata->project->wms_path);
     appdata->project->wms_path = g_strdup(wms->path);
-    project_dirty = TRUE;
+    appdata->project->dirty = TRUE;
   }
 
-  if(project_dirty)
-    project_save(appdata, appdata->project);
-
   /* ----------- request capabilities -------------- */
   gboolean path_contains_qm = (strchr(wms->path, '?') != NULL);
   gboolean path_ends_with_special = 
@@ -939,6 +952,10 @@ void wms_import(appdata_t *appdata) {
   char *filename = g_strdup_printf("%s/wms.%s", appdata->project->path, 
 				   exts[format]);
 
+
+  /* remove any existing image before */
+  wms_remove(appdata);
+
   if(!wms_download(url, filename)) {
     g_free(filename);
     g_free(url);
@@ -955,6 +972,8 @@ void wms_import(appdata_t *appdata) {
   /* --------- free wms structure -----------------*/
   wms_free(wms);
 
+  gtk_widget_set_sensitive(appdata->menu_item_wms_clear, TRUE);
+  gtk_widget_set_sensitive(appdata->menu_item_wms_adjust, TRUE);
 }
 
 /* try to load an existing image into map */
@@ -967,8 +986,22 @@ void wms_load(appdata_t *appdata) {
 				     exts[i]);
 
     if(g_file_test(filename, G_FILE_TEST_EXISTS)) {
+      appdata->map->bg_offset.x = appdata->project->wms_offset.x;
+      appdata->map->bg_offset.y = appdata->project->wms_offset.y;
+
       map_set_bg_image(appdata->map, filename);
+
+      /* restore image to saved position */
+      gint x = appdata->osm->bounds->min.x + appdata->map->bg_offset.x;
+      gint y = appdata->osm->bounds->min.y + appdata->map->bg_offset.y;
+      canvas_image_move(appdata->map->bg_item, x, y, 
+			appdata->map->bg_scale.x, appdata->map->bg_scale.y);
+
       g_free(filename);
+
+      gtk_widget_set_sensitive(appdata->menu_item_wms_clear, TRUE);
+      gtk_widget_set_sensitive(appdata->menu_item_wms_adjust, TRUE);
+
       return;
     }
     g_free(filename);
@@ -980,6 +1013,13 @@ void wms_remove(appdata_t *appdata) {
   const char *exts[] = { "png", "gif", "jpg", "" };
   int i=0;
 
+  /* this cancels any wms adjustment in progress */
+  if(appdata->map->action == MAP_ACTION_BG_ADJUST)
+    map_action_cancel(appdata);
+
+  gtk_widget_set_sensitive(appdata->menu_item_wms_clear, FALSE);
+  gtk_widget_set_sensitive(appdata->menu_item_wms_adjust, FALSE);
+
   map_remove_bg_image(appdata->map);
 
   while(exts[i][0]) {
